@@ -1,4 +1,5 @@
-package XS::Install::FrozenShit::Typemaps;
+package 
+    XS::Install::FrozenShit::Typemaps;
 use 5.006001;
 use strict;
 use warnings;
